package org.clapper.qr

import net.glxn.qrgen._
import grizzled.file.GrizzledFile._

/** The launched conscript entry point */
class QR extends xsbti.AppMain {
  def run(config: xsbti.AppConfiguration) = {
    Exit(QR.run(config.arguments))
  }
}

object QR {
  /** Shared by the launched version and the runnable version,
    * returns the process status code
    */
  def run(args: Array[String]): Int = {
    args.toList match {
      case s :: outputPath :: Nil =>
        generate(s, outputPath)
      case s :: Nil =>
        generate(s, "qr.png")
      case _ =>
        usage()
    }
  }

  /** Standard runnable class entrypoint */
  def main(args: Array[String]) {
    System.exit(run(args))
  }

  private def generate(s: String, outputPath: String): Int = {
    QRCode.from(s).file().copyTo(outputPath)
    System.err.println(s"$s -> $outputPath")
    0
  }

  private def usage(): Int = {
    System.err.print(
      """qr %s
        |Usage: qr string [path]
        |
        |Generate a QR code image containing the specified STRING, writing
        |the output to PATH. If PATH isn't specified, use "./qr.png".
        |""".stripMargin format(BuildInfo.version)
    )
    1
  }
}

case class Exit(val code: Int) extends xsbti.Exit
